%global momorel 1
%global srcname %{name}-%{version}

Summary: Dovecot Secure imap server
Name: dovecot
Version: 1.2.1
Release: %{momorel}m%{?dist}
License: MIT and LGPLv2+ and Public Domain and Modified BSD
Group: System Environment/Daemons

%global build_postgres 1
%global build_mysql 1
%global build_sqlite 1
%global build_ldap 1
%global build_gssapi 1

%global build_sieve 1
%global build_managesieve 1
%global sieve_version 0.1.8
%global sieve_name dovecot-1.2-sieve
%global managesieve_version 0.11.7
%global managesieve_name dovecot-1.2-managesieve

URL: http://www.dovecot.org/
Source0: http://www.dovecot.org/releases/1.2/%{srcname}.tar.gz
NoSource: 0
Source1: dovecot.init
Source2: dovecot.pam
Source3: maildir-migration.txt
Source4: migrate-folders
Source5: migrate-users
Source6: perfect_maildir.pl
Source7: dovecot-REDHAT-FAQ.txt
Source8: http://www.rename-it.nl/dovecot/1.2/%{sieve_name}-%{sieve_version}.tar.gz
NoSource: 8
Source9: dovecot.sysconfig
Source10: http://www.rename-it.nl/dovecot/1.2/%{managesieve_name}-%{managesieve_version}.tar.gz
NoSource: 10
Source11: http://www.rename-it.nl/dovecot/1.2/dovecot-%{version}-managesieve-%{managesieve_version}.diff.gz
NoSource: 11

Patch1: dovecot-1.1-default-settings.patch
Patch2: dovecot-1.0.beta2-mkcert-permissions.patch
Patch3: dovecot-1.0.rc7-mkcert-paths.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: openssl-devel
BuildRequires: pam-devel
BuildRequires: zlib-devel
BuildRequires: libtool
BuildRequires: autoconf >= 2.61
BuildRequires: automake
BuildRequires: pkgconfig

# gettext-devel is needed for running autoconf because of the
# presence of AM_ICONV
BuildRequires: gettext-devel

# Explicit Runtime Requirements
Requires: openssl >= 0.9.7f-4

# Package includes an initscript service file, needs to require initscripts package
Requires: initscripts
Requires(pre): shadow-utils
Requires(post): chkconfig, shadow-utils
Requires(preun): shadow-utils, chkconfig, initscripts
Requires(postun): initscripts

%if %{build_postgres}
BuildRequires: postgresql-devel >= 8.2.3
%endif

%if %{build_mysql}
BuildRequires: mysql-devel >= 5.1.32
%endif

%if %{build_sqlite}
BuildRequires: sqlite-devel
%endif

%if %{build_ldap}
BuildRequires: openldap-devel >= 2.4.0
%endif

%if %{build_gssapi}
BuildRequires: krb5-devel
%endif

%global docdir %{_docdir}/%{name}
%global ssldir %{_sysconfdir}/pki/%{name}

%description
Dovecot is an IMAP server for Linux/UNIX-like systems, written with security 
primarily in mind.  It also contains a small POP3 server.  It supports mail 
in either of maildir or mbox formats.

The SQL drivers and authentication plugins are in their subpackages.

%if %{build_sieve}
%package sieve
Requires: %{name} = %{version}-%{release}
Summary: CMU Sieve plugin for dovecot LDA
Group: System Environment/Daemons
License: MIT and LGPLv2+

%description sieve
This package provides the CMU Sieve plugin version %{sieve_version} for dovecot LDA.
%endif

%if %{build_managesieve}
%package managesieve
Requires: %{name} = %{version}-%{release}
Summary: Manage Sieve daemon for dovecot
Group: System Environment/Daemons
License: LGPLv2

%description managesieve
This package provides the Manage Sieve daemon version %{managesieve_version} for dovecot.
%endif

%if %{build_postgres}
%package pgsql
Requires: %{name} = %{version}-%{release}
Summary: Postgres SQL backend for dovecot
Group: System Environment/Daemons
%description pgsql
This package provides the Postgres SQL backend for dovecot-auth etc.
%endif

%if %{build_mysql}
%package mysql
Requires: %{name} = %{version}-%{release}
Summary: MySQL backend for dovecot
Group: System Environment/Daemons
%description mysql
This package provides the MySQL backend for dovecot-auth etc.
%endif

%if %{build_sqlite}
%package sqlite
Requires: %{name} = %{version}-%{release}
Summary: SQLite backend for dovecot
Group: System Environment/Daemons
%description sqlite
This package provides the SQLite backend for dovecot-auth etc.
%endif

%if %{build_ldap}
%package ldap
Requires: %{name} = %{version}-%{release}
Summary: LDAP auth plugin for dovecot
Group: System Environment/Daemons
%description ldap
This package provides the LDAP auth plugin for dovecot-auth etc.
%endif

%if %{build_gssapi}
%package gssapi
Requires: %{name} = %{version}-%{release}
Summary: GSSAPI auth mechanism plugin for dovecot
Group: System Environment/Daemons
%description gssapi
This package provides the GSSAPI auth mechanism plugin for dovecot-auth etc.
%endif

%package devel
Requires: %{name} = %{version}-%{release}
Summary: Development files dor dovecot
Group: Development/Libraries
%description devel
This package provides the development files for dovecot.

%prep
%setup -q -n %{srcname}

zcat %{SOURCE11} | patch -p1 --fuzz=0 -s
%patch1 -p1 -b .default-settings
%patch2 -p1 -b .mkcert-permissions
%patch3 -p1 -b .mkcert-paths

%if %{build_sieve}
%setup -q -n %{srcname} -D -T -a 8
%endif

%if %{build_managesieve}
%setup -q -n %{srcname} -D -T -a 10
%endif

%build
rm -f ./configure
libtoolize -f
autoreconf
%configure                           \
    INSTALL_DATA="install -c -p -m644" \
    --enable-header-install      \
    --disable-static             \
%if %{build_postgres}
    --with-pgsql                 \
%endif
%if %{build_mysql}
    --with-mysql                 \
%endif
%if %{build_sqlite}
    --with-sqlite                \
%endif
    --with-sql=plugin            \
    --with-sql-drivers           \
    --with-ssl=openssl           \
    --with-ssldir=%{ssldir}      \
%if %{build_ldap}
    --with-ldap=plugin           \
%endif
%if %{build_gssapi}
    --with-gssapi=plugin
%endif

make %{?_smp_mflags}

%if %{build_sieve}
cd %{sieve_name}-%{sieve_version}

rm -f ./configure
libtoolize -f
autoreconf
%configure                           \
    INSTALL_DATA="install -c -p -m644" \
    --disable-static                 \
    --with-dovecot=../

make %{?_smp_mflags}
%endif

%if %{build_managesieve}
cd ..
cd %{managesieve_name}-%{managesieve_version}

rm -f ./"configure"
autoreconf -i -f
%configure                           \
    INSTALL_DATA="install -c -p -m644" \
    --disable-static                 \
    --with-dovecot=../               \
    --with-dovecot-sieve=../%{sieve_name}-%{sieve_version}/

make %{?_smp_mflags}
%endif

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_datadir}/%{name}

install -p -m 755 src/plugins/convert/convert-tool %{buildroot}%{_libexecdir}/%{name}

mkdir -p %{buildroot}%{_initscriptdir}
install -p -m 755 %{SOURCE1} %{buildroot}%{_initscriptdir}/dovecot

mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/dovecot

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 600 %{SOURCE9} %{buildroot}%{_sysconfdir}/sysconfig/dovecot

# generate ghost .pem file
mkdir -p %{buildroot}%{ssldir}/certs
mkdir -p %{buildroot}%{ssldir}/private
touch %{buildroot}%{ssldir}/certs/dovecot.pem
chmod 600 %{buildroot}%{ssldir}/certs/dovecot.pem
touch %{buildroot}%{ssldir}/private/dovecot.pem
chmod 600 %{buildroot}%{ssldir}/private/dovecot.pem

mkdir -p %{buildroot}/var/run/dovecot/login
chmod 755 %{buildroot}/var/run/dovecot
chmod 700 %{buildroot}/var/run/dovecot/login
	
# Install dovecot.conf and dovecot-openssl.cnf
mkdir -p %{buildroot}%{ssldir}
install -p -m644 dovecot-example.conf %{buildroot}%{_sysconfdir}/dovecot.conf
rm -f %{buildroot}%{_sysconfdir}/dovecot-*example.conf # dovecot seems to install this by itself
install -p -m644 doc/dovecot-openssl.cnf %{buildroot}%{ssldir}/dovecot-openssl.cnf

# Install some of our own documentation
install -p -m644 %{SOURCE7} %{buildroot}%{docdir}/REDHAT-FAQ.txt

# Install the licensing files into the documentation area
install -p -m644 COPYING* %{buildroot}%{docdir}

mkdir -p %{buildroot}%{docdir}/examples/
install -p -m755 doc/mkcert.sh %{buildroot}%{_libexecdir}/%{name}/mkcert.sh
for f in `cd doc; echo *.conf`; do
     install -p -m644 doc/$f %{buildroot}%{docdir}/examples/$f;
done

install -p -m755 -d %{buildroot}%{docdir}/UW-to-Dovecot-Migration
for f in %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6}
do
    install -p -m644 $f %{buildroot}%{docdir}/UW-to-Dovecot-Migration
done

mv %{buildroot}%{docdir} %{buildroot}%{docdir}-%{version}
mkdir -p %{buildroot}/var/lib/dovecot

%if %{build_sieve}
# dovecot-sieve
pushd %{sieve_name}-%{sieve_version}
make install DESTDIR=%{buildroot}
popd
%endif

%if %{build_managesieve}
# dovecot-managesieve
pushd %{managesieve_name}-%{managesieve_version}
make install DESTDIR=%{buildroot}
popd
%endif

#remove the libtool archives
find %{buildroot}%{_libdir}/%{name}/ -name '*.a' -or -name '*.la' | xargs rm -f

#prepare the filelist
(
    find %{buildroot}%{_libdir}/%{name} -type d | sed -e "s|^|%dir |";
    find %{buildroot}%{_libdir}/%{name} -! -type d | \
        grep -v 'dovecot-config\|lib90_sieve_plugin\.so\|libdriver_.*\.so\|libauthdb_.*\.so\|libmech_.*\.so';
) | sed -e "s|%{buildroot}||" >libs.filelist

%clean
rm -rf %{buildroot}

%pre
getent group dovecot >/dev/null || groupadd -r dovecot
getent passwd dovecot >/dev/null || \
useradd -r -g dovecot -d /usr/libexec/dovecot -s /sbin/nologin -c "Dovecot IMAP server" dovecot
exit 0

%post
/sbin/chkconfig --add %{name}
# generate the ssl certificates
if [ ! -f %{ssldir}/certs/%{name}.pem ]; then
    SSLDIR=%{ssldir} OPENSSLCONFIG=%{ssldir}/dovecot-openssl.cnf \
         %{_libexecdir}/%{name}/mkcert.sh &> /dev/null
fi

if ! test -f /var/run/dovecot/login/ssl-parameters.dat; then
    dovecot --build-ssl-parameters &>/dev/null
fi
exit 0

%preun
if [ $1 = 0 ]; then
    /sbin/service %{name} stop > /dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi

%postun
if [ "$1" -ge "1" ]; then
    /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%files -f libs.filelist
%defattr(-,root,root,-)
%doc %{docdir}-%{version}
%config(noreplace) %{_sysconfdir}/dovecot.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/dovecot
%{_initscriptdir}/dovecot
%config(noreplace) %{_sysconfdir}/pam.d/dovecot
%dir %{ssldir}
%dir %{ssldir}/certs
%dir %{ssldir}/private
%config(noreplace) %{ssldir}/dovecot-openssl.cnf
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/certs/dovecot.pem
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/private/dovecot.pem
%{_libexecdir}/%{name}
%exclude %{_libexecdir}/%{name}/managesieve
%exclude %{_libexecdir}/%{name}/managesieve-login
%{_sbindir}/dovecot
%{_sbindir}/dovecotpw
%attr(0755,root,dovecot) %dir /var/run/dovecot
%attr(0750,root,dovecot) %dir /var/run/dovecot/login
#%%attr(0755,root,dovecot) %{_libexecdir}/%{name}/mkcert.sh
%attr(0750,dovecot,dovecot) %dir /var/lib/dovecot

%if %{build_sieve}
%files sieve
%defattr(-,root,root,-)
%{_libdir}/%{name}/lda/lib90_sieve_plugin.so
%{_bindir}/sieve-filter
%{_bindir}/sieve-test
%{_bindir}/sievec
%{_bindir}/sieved
%{_mandir}/man1/sieve-test.1*
%{_mandir}/man1/sievec.1*
%{_mandir}/man1/sieved.1*
%endif

%if %{build_managesieve}
%files managesieve
%defattr(-,root,root,-)
%{_libexecdir}/%{name}/managesieve
%{_libexecdir}/%{name}/managesieve-login
%endif

%if %{build_mysql}
%files mysql
%defattr(-,root,root,-)
%{_libdir}/%{name}/sql/libdriver_mysql.so
%{_libdir}/%{name}/auth/libdriver_mysql.so
%{_libdir}/%{name}/dict/libdriver_mysql.so
%endif

%if %{build_postgres}
%files pgsql
%defattr(-,root,root,-)
%{_libdir}/%{name}/sql/libdriver_pgsql.so
%{_libdir}/%{name}/auth/libdriver_pgsql.so
%{_libdir}/%{name}/dict/libdriver_pgsql.so
%endif

%if %{build_sqlite}
%files sqlite
%defattr(-,root,root,-)
%{_libdir}/%{name}/sql/libdriver_sqlite.so
%{_libdir}/%{name}/auth/libdriver_sqlite.so
%{_libdir}/%{name}/dict/libdriver_sqlite.so
%endif

%if %{build_ldap}
%files ldap
%defattr(-,root,root,-)
%{_libdir}/%{name}/auth/libauthdb_ldap.so
%endif

%if %{build_gssapi}
%files gssapi
%defattr(-,root,root,-)
%{_libdir}/%{name}/auth/libmech_gssapi.so
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}
%{_libdir}/%{name}/dovecot-config

%changelog
* Mon Jul 13 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2.1-1m)
- sync with Fedora 11 (1:1.2.1-1)
-- use dovecot-1.2-sieve and dovecot-1.2-managesieve

* Sun Jun 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.5.3m)
- remove duplicate files

* Sat Jun 20 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.5.2m)
- remove duplicate files

* Fri Jun 19 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.5.1m)
- update to 1.2.rc5
- enable ldap
- add managesieve based on Fedora 11 (1:1.2-0.rc5.2)

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.4.2m)
- rebuild against openssl-0.9.8k

* Thu Mar 26 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.2-0.4.1m)
- update to 1.2.beta4

* Thu Mar 19 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.3.1m)
- update to 1.2.beta3
- rebuild against mysql-5.1.32 

* Sun Feb 15 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.2.1m)
- update to 1.2.beta1

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.1.2m)
- rebuild against rpm-4.6

* Sat Jan 17 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2-0.1.1m)
- update to 1.2.alpha5
- temporarily set %%global build_ldap 0

* Sat Nov  1 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.0.15-1m)
- [SECURITY] CVE-2008-4577
-- import security patch from Fedora 9 updates (1:1.0.15-14)
- update to 1.0.15
- update sieve plugin to 1.0.3

* Wed Jun  4 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (1.0.13-3m)
- rebuild against openssl-0.9.8h-1m

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.13-2m)
- rebuild against gcc43

* Thu Mar 13 2008 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.13-1m)
- up to 1.0.13
- [SECURITY] CVE-2008-1199 CVE-2008-1218

* Tue Feb 26 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.10-4m) 
- fix sieverel

* Tue Feb 26 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.10-3m)
- rebuild against openldap-2.4.8

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.10-2m)
- %%NoSource -> NoSource

* Wed Jan  2 2008 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.10-1m)
- up to 1.0.10
- [SECURITY] CVE-2007-6598
- [SECURITY] http://www.dovecot.org/list/dovecot-news/2007-December/000057.html

* Thu Dec 13 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.9-1m)
- up to 1.0.9

* Fri Nov 30 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.8-1m)
- up to 1.0.8

* Tue Oct 30 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.7-1m)
- up to 1.0.7

* Sun Oct 28 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.6-1m)
- up to 1.0.6

* Tue Sep 11 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.5-1m)
- up to 1.0.5
- update sieve plugin to 1.0.2

* Thu Aug  2 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.3-1m)
- up to 1.0.3

* Tue Jul 17 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.2-1m)
- up to 1.0.2

* Sat Jun 16 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.1-1m)
- up to 1.0.1

* Sat Apr 14 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0.0-1m)
- up to 1.0.0

* Mon Apr  9 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0-0.931-2m)
- increase release, yum can not handle same version same release (dovecot-sieve-1.0.1-1m)
- dovecot-sieve should be provided independent release number like kdebindings

* Mon Apr  9 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.931-1m)
- up to 1.0.rc31
- [SECURITY] zlib plugin allows opening any gziped mboxes
  <http://www.dovecot.org/list/dovecot-news/2007-March/000038.html>

* Sat Mar 24 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.928-1m)
- version up 1.0.rc28
- sync fedora devel (add dovecot-sieve package)

* Wed Mar 14 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.927-1m)
- up to 1.0.rc27

* Sun Mar 11 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0-0.926-2m)
- rebuild against postgresql-8.2.3

* Wed Mar  7 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.926-1m)
- up to 1.0.rc26

* Fri Mar  2 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.925-1m)
- up to 1.0.rc25

* Fri Feb 23 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.924-1m)
- up to 1.0.rc24

* Tue Feb 20 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.923-1m)
- version up 1.0.rc23

* Mon Feb 12 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.0-0.922-2m)
- delete libtool library

* Wed Feb 07 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.922-1m)
- version up 1.0.rc22

* Fri Feb 02 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.921-1m)
- version up 1.0.rc21

* Fri Feb 02 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.920-1m)
- version up 1.0.rc20

* Wed Jan 24 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.919-1m)
- version up 1.0.rc19

* Tue Jan 23 2007 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.918-1m)
- version up 1.0.rc18

* Sun Jan  7 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0-0.917.1m)
- up to RC 17
- add BuildRequires: autoconf >= 2.61

* Sat Nov 25 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.915-1m)
- [SECURITY] CVE-2006-5973
- version up 1.0.rc15
- sync fc-6

* Thu Nov  8 2006 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.912.2m)
- namespace hack for apple mail

* Thu Nov  7 2006 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.912.1m)
- up to RC 12

* Wed Oct 18 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.0-0.96.2m)
- change autoreconf to each autotools

* Wed Aug  9 2006 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.0-0.96.1m)
- up to 1.0rc6

* Tue Jun  6 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0-0.8.2m)
- modify Prereq for new shadow-utils

* Fri May 19 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.0-0.8.1m)
- sync with fc-devel (1.0-0.beta7.1)
- version up to 1.0.beta8

* Tue May 17 2006 Yasuo Ohgaki <yohgaki@momonga-linux.org>
- (0.99.14-7m)
- rebuild against mysql 5.0.22-1m

* Sun Apr  9 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.99.14-6m)
- rebuild against openldap-2.3.19

* Sat Jan 14 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.99.14-5m)
- rebuild against openldap-2.3.11

* Sat Nov 19 2005 Shigeyuki Yamashita <shige@momonga-linux.org>
- (0.99.14-4m)
- rebuild against postgresql-8.1.0

* Mon Sep  5 2005 YONEKAWA Susumu <yonekawa@mmg.roka.jp>
- (0.99.14-3m)
- rebuild against for MySQL-4.1.14

* Mon Apr 25 2005 Toru Hoshina <t@momonga-linux.org>
- (0.99.14-2m)
- rebuild against postgresql-8.0.2.

* Fri Mar 11 2005 Hiroyuki Koga <kuma@momonga-linux.org>
- (0.99.14-1m)
- several fixes

* Mon Jan 10 2005 Hiroyuki Koga <kuma@momonga-linux.org>
- (0.99.13-1m)
- update to 0.99.13

* Fri Nov 19 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.99.11-2m)
- more momonganize

* Fri Oct 22 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (0.99.11-1m)
- import to momonga

* Thu Sep 30 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.3
- fix bug #124786, listen to ipv6 as well as ipv4

* Wed Sep  8 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.1
- bring up to latest upstream,
  comments from Timo Sirainen <tss at iki.fi> on release v0.99.11 2004-09-04
  + 127.* and ::1 IP addresses are treated as secured with
    disable_plaintext_auth = yes
  + auth_debug setting for extra authentication debugging
  + Some documentation and error message updates
  + Create PID file in /var/run/dovecot/master.pid
  + home setting is now optional in static userdb
  + Added mail setting to static userdb
  - After APPENDing to selected mailbox Dovecot didn't always notice the
    new mail immediately which broke some clients
  - THREAD and SORT commands crashed with some mails
  - If APPENDed mail ended with CR character, Dovecot aborted the saving
  - Output streams sometimes sent data duplicated and lost part of it.
    This could have caused various strange problems, but looks like in
    practise it rarely caused real problems.

* Wed Aug  4 2004 John Dennis <jdennis@redhat.com>
- change release field separator from comma to dot, bump build number

* Mon Aug  2 2004 John Dennis <jdennis@redhat.com> 0.99.10.9-1,FC3,1
- bring up to date with latest upstream, fixes include:
- LDAP support compiles now with Solaris LDAP library
- IMAP BODY and BODYSTRUCTURE replies were wrong for MIME parts which
  didn't contain Content-Type header.
- MySQL and PostgreSQL auth didn't reconnect if connection was lost
  to SQL server
- Linking fixes for dovecot-auth with some systems
- Last fix for disconnecting client when downloading mail longer than
  30 seconds actually made it never disconnect client. Now it works
  properly: disconnect when client hasn't read _any_ data for 30
  seconds.
- MySQL compiling got broken in last release
- More PostgreSQL reconnection fixing


* Mon Jul 26 2004 John Dennis <jdennis@redhat.com> 0.99.10.7-1,FC3,1
- enable postgres and mySQL in build
- fix configure to look for mysql in alternate locations
- nuke configure script in tar file, recreate from configure.in using autoconf

- bring up to latest upstream, which included:
- Added outlook-pop3-no-nuls workaround to fix Outlook hang in mails with NULs.
- Config file lines can now contain quoted strings ("value ")
- If client didn't finish downloading a single mail in 30 seconds,
  Dovecot closed the connection. This was supposed to work so that
  if client hasn't read data at all in 30 seconds, it's disconnected.
- Maildir: LIST now doesn't skip symlinks


* Wed Jun 30 2004 John Dennis <jdennis@redhat.com>
- bump rev for build
- change rev for FC3 build

* Fri Jun 25 2004 John Dennis <jdennis@redhat.com> - 0.99.10.6-1
- bring up to date with upstream,
  recent change log comments from Timo Sirainen were:
  SHA1 password support using OpenSSL crypto library
  mail_extra_groups setting
  maildir_stat_dirs setting
  Added NAMESPACE capability and command
  Autocreate missing maildirs (instead of crashing)
  Fixed occational crash in maildir synchronization
  Fixed occational assertion crash in ioloop.c
  Fixed FreeBSD compiling issue
  Fixed issues with 64bit Solaris binary

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu May 27 2004 David Woodhouse <dwmw2@redhat.com> 0.99.10.5-1
- Update to 0.99.10.5 to fix maildir segfaults (#123022)

* Fri May 07 2004 Warren Togami <wtogami@redhat.com> 0.99.10.4-4
- default auth config that is actually usable
- Timo Sirainen (author) suggested functionality fixes
  maildir, imap-fetch-body-section, customflags-fix

* Mon Feb 23 2004 Tim Waugh <twaugh@redhat.com>
- Use ':' instead of '.' as separator for chown.

* Tue Feb 17 2004 Jeremy Katz <katzj@redhat.com> - 0.99.10.4-3
- restart properly if it dies (#115594)

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Nov 24 2003 Jeremy Katz <katzj@redhat.com> 0.99.10.4-1
- update to 0.99.10.4

* Mon Oct  6 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-7
- another patch from upstream to fix returning invalid data on partial
  BODY[part] fetches
- patch to avoid confusion of draft/deleted in indexes

* Tue Sep 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-6
- add some patches from upstream (#104288)

* Thu Sep  4 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-5
- fix startup with 2.6 with patch from upstream (#103801)

* Tue Sep  2 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-4
- fix assert in search code (#103383)

* Tue Jul 22 2003 Nalin Dahyabhai <nalin@redhat.com> 0.99.10-3
- rebuild

* Thu Jul 17 2003 Bill Nottingham <notting@redhat.com> 0.99.10-2
- don't run by default

* Thu Jun 26 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-1
- 0.99.10

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.2
- 0.99.10-rc2 (includes ssl detection fix)
- a few tweaks from fedora
  - noreplace the config file
  - configure --with-ldap to get LDAP enabled

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.1
- 0.99.10-rc1
- add fix for ssl detection
- add zlib-devel to BuildRequires
- change pam service name to dovecot
- include pam config

* Thu May  8 2003 Jeremy Katz <katzj@redhat.com> 0.99.9.1-1
- update to 0.99.9.1
- add patch from upstream to fix potential bug when fetching with
  CR+LF linefeeds
- tweak some things in the initscript and config file noticed by the
  fedora folks

* Sun Mar 16 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-2
- fix ssl dir
- own /var/run/dovecot/login with the correct perms
- fix chmod/chown in post

* Fri Mar 14 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-1
- update to 0.99.8.1

* Tue Mar 11 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-2
- add a patch to fix quoting problem from CVS

* Mon Mar 10 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-1
- 0.99.8
- add some buildrequires
- fixup to build with openssl 0.9.7
- now includes a pop3 daemon (off by default)
- clean up description and %%preun
- add dovecot user (uid/gid of 97)
- add some buildrequires
- move the ssl cert to %{_datadir}/ssl/certs
- create a dummy ssl cert in %post
- own /var/run/dovecot
- make the config file a source so we get default mbox locks of fcntl

* Sun Dec  1 2002 Seth Vidal <skvidal@phy.duke.edu>
- 0.99.4 and fix startup so it starts imap-master not vsftpd :)

* Tue Nov 26 2002 Seth Vidal <skvidal@phy.duke.edu>
- first build
